#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-01-10
#Desc:
#


from colinwsLogs import printLog, errorLog, warnLog
from colinwsDate import today, tommorrow, yesterday, daytime, dayBefore, dayAfter, firstAndLastDay
__author__ = 'Colin'
# __all__ = ['colinwsLogs', 'colinwsDate']
__version__ = '1.0.5'
